@@ -59,7 +59,7 @@ public:
     /**
      *  Destructor.
      */
-    virtual ~KisApplication();
+    ~KisApplication() override;
 
     /**
      * Call this to start the application.
@@ -93,7 +93,7 @@ public:
     void hideSplashScreen();
 
     /// Overridden to handle exceptions from event handlers.
-    bool notify(QObject *receiver, QEvent *event);
+    bool notify(QObject *receiver, QEvent *event) override;
 
 public Q_SLOTS:
 
