@@ -101,28 +101,34 @@ struct KisDisplayColorConverter::Private
 
     class DisplayRenderer : public KoColorDisplayRendererInterface {
     public:
-        DisplayRenderer(KisDisplayColorConverter *parent, KoCanvasResourceManager *resourceManager)
-            : m_parent(parent),
+        DisplayRenderer(KisDisplayColorConverter *displayColorConverter, KoCanvasResourceManager *resourceManager)
+            : m_displayColorConverter(displayColorConverter),
               m_resourceManager(resourceManager)
         {
-            parent->connect(parent, SIGNAL(displayConfigurationChanged()),
+            displayColorConverter->connect(displayColorConverter, SIGNAL(displayConfigurationChanged()),
                             this, SIGNAL(displayConfigurationChanged()));
         }
 
+        QImage convertToQImage(const KoColorSpace *srcColorSpace, const quint8 *data, qint32 width, qint32 height) const override {
+            KisPaintDeviceSP dev = new KisPaintDevice(srcColorSpace);
+            dev->writeBytes(data, 0, 0, width, height);
+            return m_displayColorConverter->toQImage(dev);
+        }
+
         QColor toQColor(const KoColor &c) const override {
-            return m_parent->toQColor(c);
+            return m_displayColorConverter->toQColor(c);
         }
 
         KoColor approximateFromRenderedQColor(const QColor &c) const override {
-            return m_parent->approximateFromRenderedQColor(c);
+            return m_displayColorConverter->approximateFromRenderedQColor(c);
         }
 
         KoColor fromHsv(int h, int s, int v, int a) const override {
-            return m_parent->fromHsv(h, s, v, a);
+            return m_displayColorConverter->fromHsv(h, s, v, a);
         }
 
         void getHsv(const KoColor &srcColor, int *h, int *s, int *v, int *a) const override {
-            m_parent->getHsv(srcColor, h, s, v, a);
+            m_displayColorConverter->getHsv(srcColor, h, s, v, a);
         }
 
         qreal minVisibleFloatValue(const KoChannelInfo *chaninfo) const override {
@@ -142,11 +148,11 @@ struct KisDisplayColorConverter::Private
         }
 
         const KoColorSpace* getPaintingColorSpace() const override {
-            return m_parent->paintingColorSpace();
+            return m_displayColorConverter->paintingColorSpace();
         }
 
     private:
-        KisDisplayColorConverter *m_parent;
+        KisDisplayColorConverter *m_displayColorConverter;
         QPointer<KoCanvasResourceManager> m_resourceManager;
     };
 
