@@ -476,6 +476,10 @@ QVariant KisNodeModel::data(const QModelIndex &index, int role) const
 
             QSize size = node->extent().size();
             size.scale(maxSize, maxSize, Qt::KeepAspectRatio);
+            if (size.width() == 0 || size.height() == 0) {
+                // No thumbnail can be shown if there isn't width or height...
+                return QVariant();
+            }
 
             return node->createThumbnail(size.width(), size.height());
         } else {
@@ -606,7 +610,7 @@ QMimeData * KisNodeModel::mimeData(const QModelIndexList &indexes) const
         nodes << nodeFromIndex(idx);
     }
 
-    return KisMimeData::mimeForLayers(nodes, m_d->image->rootLayer());
+    return KisMimeData::mimeForLayers(nodes, m_d->image);
 }
 
 bool KisNodeModel::dropMimeData(const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent)
