@@ -29,9 +29,13 @@ class KisVideoExport : public KisImportExportFilter
     Q_OBJECT
 public:
     KisVideoExport(QObject *parent, const QVariantList &);
-    virtual ~KisVideoExport();
+    ~KisVideoExport() override;
 public:
-    virtual KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
+    KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0) override;
+
+    KisPropertiesConfigurationSP defaultConfiguration(const QByteArray& from, const QByteArray& to) const override;
+    KisPropertiesConfigurationSP lastSavedConfiguration(const QByteArray &from, const QByteArray &to) const override;
+    KisConfigWidget *createConfigurationWidget(QWidget *parent, const QByteArray& from = "", const QByteArray& to = "") const override;
 };
 
 #endif
