@@ -32,7 +32,6 @@
 #include "kis_selection_tool_helper.h"
 #include "kis_shape_tool_helper.h"
 
-#include "kis_system_locker.h"
 #include "KisViewManager.h"
 #include "kis_selection_manager.h"
 
@@ -53,12 +52,8 @@ void __KisToolSelectRectangularLocal::finishRect(const QRectF& rect)
     KisSelectionToolHelper helper(kisCanvas, kundo2_i18n("Select Rectangle"));
 
     QRect rc(rect.normalized().toRect());
-    helper.cropRectIfNeeded(&rc, selectionAction());
 
-    // If the user just clicks on the canvas deselect
-    if (helper.canShortcutToDeselect(rc, selectionAction())) {
-        // Queueing this action to ensure we avoid a race condition when unlocking the node system
-        QTimer::singleShot(0, kisCanvas->viewManager()->selectionManager(), SLOT(deselect()));
+    if (helper.tryDeselectCurrentSelection(pixelToView(rc), selectionAction())) {
         return;
     }
 
